<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>command not found</source>
        <translation>Impossibile eseguire il comando</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Operation successfully completed.</source>
        <translation>Operazioni compiuta con successo.</translation>
    </message>
    <message>
        <source>An error has occurs during the operation.</source>
        <translation>E&apos; occorso un errore durante l&apos;operazione.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_new call.</source>
        <translation>Un errore è occorso durante la chiamata ped_disk_new.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_get_partition call.</source>
        <translation>Un errore è occorso durante la chiamata ped_disk_get_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_new call.</source>
        <translation>Un errore è occorso durante la chiamata ped_partition_new.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_add_partition call.</source>
        <translation>Un errore è occorso durante la chiamata ped_disk_add_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_system call.</source>
        <translation>Un errore è occorso durante la chiamata ped_partition_set_system.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_flag call.</source>
        <translation>Un errore è occorso durante la chiamata ped_partition_set_flag.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_delete_partition call.</source>
        <translation>Un errore è occorso durante la chiamata ped_disk_delete_partition.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>A program that create NTFS partitions.</source>
        <translation>Un programma che crea partizioni NTFS.</translation>
    </message>
    <message>
        <source>A program that resize NTFS partitions.</source>
        <translation>Un programma che ridimensiona partizioni NTFS.</translation>
    </message>
    <message>
        <source>A program that create EXT3 partitions.</source>
        <translation>Un programma che crea partizioni EXT3.</translation>
    </message>
    <message>
        <source>A program that create JFS partitions.</source>
        <translation>Un programma che crea partizioni JFS.</translation>
    </message>
    <message>
        <source>A program that create XFS partitions.</source>
        <translation>Un programma che crea partizioni XFS.</translation>
    </message>
    <message>
        <source>Cannot read /proc/partitions, QTParted cannot be used!.
Please use a kernel with /proc/partitions support.</source>
        <translation type="obsolete">Impossibile leggere /proc/partitions, QTParted non può essere usato!
E&apos; necessario usare un kernel con il supporto di /proc/partitions.</translation>
    </message>
    <message>
        <source>Cannot get parted version.</source>
        <translation>Non riesco a rilevare la versione in uso di QTParted.</translation>
    </message>
    <message>
        <source>Parted is too old:
- installed parted version: %1.%2.%3
- required parted version: %4.%5.%6 (or better)

Parted homepage: http://www.gnu.org/software/parted/</source>
        <translation>La release di Parted installata è troppo vecchia:
- versione di parted installata: %1.%2.%3
- versione di parted richiesta: %4.%5.%6 (o superiore)

Parted homepage: http://www.gnu.org/software/parted/</translation>
    </message>
    <message>
        <source>Cannot umount partition device: %1.Please do it by hand first to commit the changes!</source>
        <translation>Non posso smontare il dispositivo disco: %1. Per favore, fallo a mano prima di salvare le modifiche!</translation>
    </message>
    <message>
        <source>Utility for mount a filesystem.</source>
        <translation>Programma per montare un filesystem.</translation>
    </message>
    <message>
        <source>Utility for umount a filesystem.</source>
        <translation>Programma per smontare un filesystem.</translation>
    </message>
    <message>
        <source>Utility for grow a xfs filesystem.</source>
        <translation>Utility per allargare una partizione xfs.</translation>
    </message>
</context>
<context>
    <name>QP_ActionList</name>
    <message>
        <source>Getting info about partition %1.</source>
        <translation>Sto analizzando la partizione %1.</translation>
    </message>
    <message>
        <source>Creating partition.</source>
        <translation>Creando la partizione.</translation>
    </message>
    <message>
        <source>Preparation for removing a partition.</source>
        <translation>Preparazione per la rimozione di una partizione.</translation>
    </message>
    <message>
        <source>Removing a partition.</source>
        <translation>Rimozione di una partizione.</translation>
    </message>
    <message>
        <source>Preparation for resizing a partition.</source>
        <translation>Preparazione per il ridimensionamento di una partizione.</translation>
    </message>
    <message>
        <source>Resizing a partition.</source>
        <translation>Ridimensionamento di una partizione.</translation>
    </message>
    <message>
        <source>Preparation for activating a partition.</source>
        <translation>Preparazione per l&apos;attivazione di una partizione.</translation>
    </message>
    <message>
        <source>Activating a partition.</source>
        <translation>Attivazione di una partizione.</translation>
    </message>
    <message>
        <source>Preparation for formatting a partition.</source>
        <translation>Preparazione per la formattazione di una partizione.</translation>
    </message>
    <message>
        <source>Formatting a partition.</source>
        <translation>Formattazione di una partizione.</translation>
    </message>
    <message>
        <source>Rescan of the disk.</source>
        <translation>Scansionamento del disco.</translation>
    </message>
    <message>
        <source>Preparation for moving a partition.</source>
        <translation>Preparazione per lo spostamento di una partizione.</translation>
    </message>
    <message>
        <source>Moving a partition.</source>
        <translation>Spostamento di una partizione.</translation>
    </message>
    <message>
        <source>All operations completed.</source>
        <translation>Tutte le operazioni sono state compiute con successo.</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_new!</source>
        <translation>Errore critico durante una chiamata a ped_disk_new!</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_duplicate!</source>
        <translation>Errore critico durante una chiamata a ped_disk_duplicate!</translation>
    </message>
    <message>
        <source>Preparation for hiding a partition.</source>
        <translation>Preparazione per nascondere una partizione.</translation>
    </message>
    <message>
        <source>Hiding a partition.</source>
        <translation>Nascondendo una partizione.</translation>
    </message>
</context>
<context>
    <name>QP_DriveList</name>
    <message>
        <source>No device found. Maybe you&apos;re not using root user?</source>
        <translation>Nessun dispositivo trovato. Sicuro di usare l&apos;utenza di root?</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dischi</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
</context>
<context>
    <name>QP_FSExt3</name>
    <message>
        <source>Writing superblocks and filesystem.</source>
        <translation>Scrivendo il superblock e il filesystem.</translation>
    </message>
    <message>
        <source>Writing inode tables.</source>
        <translation>Scrivendo la tabella inode.</translation>
    </message>
    <message>
        <source>There was a problem with mkfs.ext3.</source>
        <translation>Un problema è occorso con mkfs.ext3.</translation>
    </message>
</context>
<context>
    <name>QP_FSJfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>Non è possibile allargare partizioni se il disco è occupato</translation>
    </message>
</context>
<context>
    <name>QP_FSNtfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>Non è possibile allargare partizioni se il disco è occupato</translation>
    </message>
    <message>
        <source>Resizing in progress.</source>
        <translation>Ridimensionamento in corso.</translation>
    </message>
    <message>
        <source>Syncing device.</source>
        <translation>Sincronizzazione del dispositivo.</translation>
    </message>
</context>
<context>
    <name>QP_FSReiserFS</name>
    <message>
        <source>No label</source>
        <translation>Nessuna etichetta</translation>
    </message>
</context>
<context>
    <name>QP_FSXfs</name>
    <message>
        <source>There was a problem with mkfs.xfs.</source>
        <translation>E&apos; occorso un problema con mkfs.xfs.</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>Non è possibile allargare partizioni se il disco è occupato</translation>
    </message>
    <message>
        <source>Error during xfs_grow.</source>
        <translation>Errore durante xfs_grow.</translation>
    </message>
</context>
<context>
    <name>QP_LibParted</name>
    <message>
        <source>Can&apos;t move extended partitions.</source>
        <translation>Non posso spostare le partizioni estese.</translation>
    </message>
    <message>
        <source>Can&apos;t move a partition onto itself. Try using resize, perhaps?</source>
        <translation>Non posso spostare una partizione su se stessa. Perché non provare con un resize?</translation>
    </message>
    <message>
        <source>The partition is mounted.</source>
        <translation>La partizione è montata.</translation>
    </message>
    <message>
        <source>An error happen during ped_geometry_init call.</source>
        <translation>Un errore è occorso durante la chiamata ped_geometry_init.</translation>
    </message>
    <message>
        <source>An error happen during ped_disk_set_partition_geom call.</source>
        <translation>Un errore è occorso durante la chiamata ped_disk_set_partition_geom.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_open call.</source>
        <translation>Un errore è occorso durante la chiamata ped_file_system_open.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_resize call.</source>
        <translation>Un errore è occorso durante la chiamata ped_file_system_resize.</translation>
    </message>
    <message>
        <source>Scanning all disk partitions.</source>
        <translation>Scansionamento delle partizioni del disco.</translation>
    </message>
    <message>
        <source>Partition %s is being used.</source>
        <translation>La partizione %s è in uso.</translation>
    </message>
    <message>
        <source>Cannot change the active status on this partition</source>
        <translation>Impossibile attivare questa partizione</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during set_system, please report it!</source>
        <translation>Un bug è occorso in QTParted durante la chiamata set_system, per favore riportalo!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during ped_file_system_type_get, please report it!</source>
        <translation>Un bug è occorso in QTParted durante la chiamata ped_file_system_type_get, per favore riportalo!</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Questa è una partizione virtuale. Non è possile cambiarla: usa undo per tornare indietro.</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;resize&quot; scan, please report it!</source>
        <translation>Un bug è stato trovato in QTParted durante la scansione per il ridimensionanto, per favore, segnalalo!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;mkfs&quot; scan, please report it!</source>
        <translation>Un bug è stato trovato in QTParted durante la creazione del filesystem, per favore, segnalalo!</translation>
    </message>
    <message>
        <source>Error committing device.
This can happen when a device is mounted in the disk.
Try to unmount all partitions on this disk.
Please read the FAQ for this kind of error!</source>
        <translation>Errore salvando le modifiche sul device.
Questo in genere accade quando un device è montato sul disco.
Prova a smontare tutte le partizioni del disco.
Per favore, leggi le FAQ per questo tipo di errore!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;move&quot; scan, please report it!</source>
        <translation>Un bug è stato trovato in QTParted durante lo spostamento di una partizione, per favore, segnalalo!</translation>
    </message>
    <message>
        <source>Cannot change the hidden status on this partition</source>
        <translation>Non posso cambiare nascondere la partizione</translation>
    </message>
</context>
<context>
    <name>QP_MainWindow</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Quit from the application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <source>&amp;Property</source>
        <translation>&amp;Proprietà</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <source>Property of the selected partition</source>
        <translation>Proprietà dalla partizione selezionata</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation>&amp;Crea</translation>
    </message>
    <message>
        <source>Create a new partition</source>
        <translation>Crea una nuova partizione</translation>
    </message>
    <message>
        <source>&amp;Resize</source>
        <translation>&amp;Ridimensiona</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation>Ridimensiona</translation>
    </message>
    <message>
        <source>Resize a partition</source>
        <translation>Ridimensiona una partizione</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Sposta</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
    <message>
        <source>Move a partition</source>
        <translation>Sposta una partizione</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Delete a new partition</source>
        <translation>Cancella una partizione</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>&amp;Operations</source>
        <translation>&amp;Operazioni</translation>
    </message>
    <message>
        <source>this is a %1 partition
it start at: %2 and end at: %3
it can grow left: %4 and right: %5
the filesystem is: %6</source>
        <translation>Questa è una partizione %1
la partizione inizia a: %2 e finisce a: %3
può crescere a sinistra fino a %4 e a destra fino a %5
il suo filesystem è: %6</translation>
    </message>
    <message>
        <source>Enter &lt;b&gt;What&apos;s This&lt;/b&gt; modeIt enables the user to ask for help about widgets on the screen.</source>
        <translation>Entra nella modalità &lt;b&gt;Cos&apos;è&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>Che &amp;Cos&apos;è</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>Che Cos&apos;è</translation>
    </message>
    <message>
        <source>About QT</source>
        <translation>Informazioni sulle librerie QT</translation>
    </message>
    <message>
        <source>Information about QT</source>
        <translation>Informazioni sulle librerie QT</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>About &amp;QTParted</source>
        <translation>Informazioni su &amp;QTParted</translation>
    </message>
    <message>
        <source>About QTParted</source>
        <translation>Informazioni su QTParted</translation>
    </message>
    <message>
        <source>Information about QTParted</source>
        <translation>Mostra informazioni su QTParted</translation>
    </message>
    <message>
        <source>About Q&amp;T</source>
        <translation>Informazioni sulle librerie Q&amp;T</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>An internal error happened during partition scan.
This means that you cannot resize or move this partition.</source>
        <translation>Un errore interno è occorso durante lo scan delle partizioni.
Non è possibile ridimensionare o spostare questa partizione.</translation>
    </message>
    <message>
        <source>&amp;Configuration...</source>
        <translation>&amp;Impostazioni...</translation>
    </message>
    <message>
        <source>Configuration of QTParted</source>
        <translation>Impostazioni di QTParted</translation>
    </message>
    <message>
        <source>Open the configuration dialog</source>
        <translation>Apre la finestra di configurazione</translation>
    </message>
    <message>
        <source>&amp;Disks</source>
        <translation>&amp;Dischi</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opzioni</translation>
    </message>
    <message>
        <source>Getting devices</source>
        <translation>Acquisizione periferiche</translation>
    </message>
    <message>
        <source>load user settings</source>
        <translation>Caricamento impostazioni personalizzate</translation>
    </message>
    <message>
        <source>primary</source>
        <translation>Primaria</translation>
    </message>
    <message>
        <source>logical</source>
        <translation>Logica</translation>
    </message>
    <message>
        <source>extended</source>
        <translation>Estesa</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Pronto</translation>
    </message>
    <message>
        <source>Set Active...</source>
        <translation>Attiva...</translation>
    </message>
    <message>
        <source>(No Active on Drive)</source>
        <translation>(Nessuna partizione attiva sul disco)</translation>
    </message>
    <message>
        <source>Currently active partition: %1
Change active partition to: %2

Are you sure you want to change the active partition?</source>
        <translation>Partizione correntemente attiva: %1
Partizione che sarà attivata: %2

Sei sicuro di voler cambiare la partizione attiva?</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Undo last operation</source>
        <translation>Annulla l&apos;ultima operazione</translation>
    </message>
    <message>
        <source>&amp;Commit</source>
        <translation>&amp;Applica</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Commit all operations</source>
        <translation>Applica tutte le operazioni</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Questa è una partizione virtuale. Non è possile cambiarla: usa undo per tornare indietro.</translation>
    </message>
    <message>
        <source>&amp;Format</source>
        <translation>&amp;Formatta</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatta</translation>
    </message>
    <message>
        <source>Format a new partition</source>
        <translation>Formatta una nuova partizione</translation>
    </message>
    <message>
        <source>&amp;Device property</source>
        <translation>&amp;Proprietà del dispositivo</translation>
    </message>
    <message>
        <source>&amp;Make a new Partition Table</source>
        <translation>&amp;Crea una nuova Tabella delle Partizioni</translation>
    </message>
    <message>
        <source>This will make the partition table</source>
        <translation>Crea una nuova tabella delle partizioni</translation>
    </message>
    <message>
        <source>You&apos;re going to loose all partition data! Are you sure? :)</source>
        <translation>Stai per perdere tutti i dati! Sei sicuro? :)</translation>
    </message>
    <message>
        <source>detected</source>
        <translation>trovato</translation>
    </message>
    <message>
        <source>none</source>
        <translation>nessuno</translation>
    </message>
    <message>
        <source>You&apos;re going to make a new partition table. Are you sure?
All data will be lost!</source>
        <translation>Stai per creare una nuova tabella delle partizioni. Sei sicuro?
Tutti i dati del disco andranno persi!</translation>
    </message>
    <message>
        <source>It was not possible to make a new partition table.</source>
        <translation>Non è stato possibile creare una nuova tabella delle partizioni.</translation>
    </message>
    <message>
        <source>Device status: readonly.</source>
        <translation>Stato del dispositivo: sola lettura.</translation>
    </message>
    <message>
        <source>Device status: busy.</source>
        <translation>Stato del dispositivo: occupato.</translation>
    </message>
    <message>
        <source>Device status: available.</source>
        <translation>Stato del dispositivo: disponibile.</translation>
    </message>
    <message>
        <source>You&apos;re commiting all changes. Warning, you can lost data!
Make sure also that you&apos;re not commiting a busy device...
In other word PLEASE UMOUNT ALL PARTITIONS before commiting changes!</source>
        <translation>Stai per applicare tutti i cambiamenti. Attenzione, potresti perdere dati!
Accertati di non applicare cambiamenti su dispositivi occupati...
In altre parole PER FAVORE SMONTA TUTTE LE PARTIZIONI prima di applicare cambiamenti!</translation>
    </message>
    <message>
        <source>&amp;Device</source>
        <translation>&amp;Dispositivo</translation>
    </message>
    <message>
        <source>See the property of this disk device</source>
        <translation>Guarda le proprietà di questo dispositivo disco</translation>
    </message>
    <message>
        <source>Some information about the disk device</source>
        <translation>Mostra alcune informazioni sul disco dispositivo</translation>
    </message>
    <message>
        <source>Set Hidden...</source>
        <translation type="obsolete">Nascondi...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
</context>
<context>
    <name>QP_NavView</name>
    <message>
        <source>The following drives have been detected:</source>
        <translation>I seguenti dischi sono stati rilevati:</translation>
    </message>
    <message>
        <source>Drive Info</source>
        <translation>Informazioni Disco</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <source>Model:</source>
        <translation>Modello:</translation>
    </message>
    <message>
        <source>Capacity (Mb):</source>
        <translation>Capacità (Mb):</translation>
    </message>
    <message>
        <source>Length sectors:</source>
        <translation>Lunghezza settori:</translation>
    </message>
    <message>
        <source>No Drive Selected</source>
        <translation>Nessun Disco Selezionato</translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Stato:</translation>
    </message>
    <message>
        <source>readonly.</source>
        <translation>sola lettura.</translation>
    </message>
    <message>
        <source>busy.</source>
        <translation>occupato.</translation>
    </message>
    <message>
        <source>available.</source>
        <translation>disponibile.</translation>
    </message>
</context>
<context>
    <name>QP_PartInfo</name>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Questa è una partizione virtuale. Non è possile cambiarla: usa undo per tornare indietro.</translation>
    </message>
    <message>
        <source>Bug during mkfs! Cannot format virtual partitions!</source>
        <translation>Un bug è stato rilevato in mkfs! Non è possibile formattare partizioni virtuali!</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="obsolete">Non è possibile allargare partizioni se il disco è occupato</translation>
    </message>
</context>
<context>
    <name>QP_RealListView</name>
    <message>
        <source>Number</source>
        <translation>Progressivo</translation>
    </message>
    <message>
        <source>Partition</source>
        <translation>Partizione</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Used space</source>
        <translation>Spazio usato</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vuota</translation>
    </message>
    <message>
        <source>Partition table</source>
        <translation>Tabella partizioni</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Nascosto</translation>
    </message>
</context>
<context>
    <name>QP_UIConfig</name>
    <message>
        <source>Configuration</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>QTParted &amp;layout</source>
        <translation>&amp;Aspetto di QTParted</translation>
    </message>
    <message>
        <source>Chart and ListBox</source>
        <translation>Grafico e dettaglio</translation>
    </message>
    <message>
        <source>Only Chart</source>
        <translation>Solo grafico</translation>
    </message>
    <message>
        <source>Only ListBox</source>
        <translation>Solo dettaglio</translation>
    </message>
    <message>
        <source>&amp;External Tools</source>
        <translation>Programmi &amp;esterni</translation>
    </message>
    <message>
        <source>&amp;Full executable path</source>
        <translation>&amp;Percorso dell&apos;eseguibile</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
<context>
    <name>QP_UICreate</name>
    <message>
        <source>Create partition</source>
        <translation>Crea una partizione</translation>
    </message>
    <message>
        <source>&amp;Size:</source>
        <translation>&amp;Dimensione:</translation>
    </message>
    <message>
        <source>Create &amp;as:</source>
        <translation>Crea &amp;come:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etichetta:</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>&amp;Tipo partizione:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>&amp;Beginning of unallocated space</source>
        <translation>&amp;Inizio dello spazio non utilizzato</translation>
    </message>
    <message>
        <source>&amp;End of unallocated space</source>
        <translation>&amp;Fine dello spazio non utilizzato</translation>
    </message>
    <message>
        <source>Pe&amp;rcent of unallocated space:</source>
        <translation>&amp;Percentuale dello spazio non utilizzato:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
<context>
    <name>QP_UIDeviceProperty</name>
    <message>
        <source>Device property</source>
        <translation>Proprità del dispositivo</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Nome corto del dispositivo</translation>
    </message>
    <message>
        <source>Device long name</source>
        <translation>Nome lungo del dispositivo</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>QP_UIFormat</name>
    <message>
        <source>Format partition</source>
        <translation>Formatta la partizione</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>O&amp;K</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>&amp;Tipo partizione:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etichetta:</translation>
    </message>
</context>
<context>
    <name>QP_UIProgress</name>
    <message>
        <source>Progress</source>
        <translation>Avanzamento</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Avanzamento:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>O&amp;K</translation>
    </message>
    <message>
        <source>Time Left:</source>
        <translation>Tempo restante:</translation>
    </message>
    <message>
        <source>Current operation:</source>
        <translation>Operazione corrente:</translation>
    </message>
</context>
<context>
    <name>QP_UIResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Ridimensiona la partizione</translation>
    </message>
    <message>
        <source>Minimum Size:</source>
        <translation>Dimensione minima:</translation>
    </message>
    <message>
        <source>Free Space &amp;Before:</source>
        <translation>Spazio libero &amp;Precedente:</translation>
    </message>
    <message>
        <source>New Size:</source>
        <translation>Nuova Dimensione:</translation>
    </message>
    <message>
        <source>Free Space &amp;After:</source>
        <translation>Spazio libero &amp;Sucessivo:</translation>
    </message>
    <message>
        <source>It is recommended to backup your data before do this operation!</source>
        <translation>E&apos; raccomandato eseguire il backup dei tuoi dati prima di questa operazione!</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>O&amp;K</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
<context>
    <name>QP_dlgAbout</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>QP_dlgCreate</name>
    <message>
        <source>This filesystem cannot be greater of %1</source>
        <translation>Questo filesystem non può essere più grande di %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgDevProperty</name>
    <message>
        <source>Devfs is enabled.</source>
        <translation>Devfs è disabilitato.</translation>
    </message>
    <message>
        <source>Devfs is disabled.</source>
        <translation>Devfs è abilitato.</translation>
    </message>
    <message>
        <source>Partition table: %1</source>
        <translation>Tabella partizioni: %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgProgress</name>
    <message>
        <source>Initializing</source>
        <translation>Inizializzazione</translation>
    </message>
    <message>
        <source>Time Left: %1</source>
        <translation>Tempo residuo: %1</translation>
    </message>
    <message>
        <source>Operation: %1 of %2.
Current operation: %3</source>
        <translation>Operazione: %1 di %2.
Operazione corrente: %3</translation>
    </message>
    <message>
        <source>Operations completed sucessfully.</source>
        <translation>Operazioni compiute con successo.</translation>
    </message>
</context>
<context>
    <name>QP_dlgResize</name>
    <message>
        <source>Minimum Size: %1 MB</source>
        <translation>Dimensione Minima: %1 MB</translation>
    </message>
    <message>
        <source>Resize partition</source>
        <translation>Ridimensiona la partizione</translation>
    </message>
    <message>
        <source>Move partition</source>
        <translation>Sposta la partizione</translation>
    </message>
</context>
</TS>
